@@ -1,11 +1,12 @@
 package matchers
 
 import (
-	"github.com/onsi/gomega/types"
-	"github.com/pkg/errors"
-	"github.com/weaveworks/eksctl/pkg/actions/nodegroup"
-
 	"encoding/json"
+	"fmt"
+
+	"github.com/onsi/gomega/types"
+
+	"github.com/weaveworks/eksctl/pkg/actions/nodegroup"
 )
 
 // BeNodeGroupsWithNamesWhich helps match JSON-formatted nodegroups by
@@ -25,11 +26,11 @@ type jsonNodeGroupMatcher struct {
 func (matcher *jsonNodeGroupMatcher) Match(actual interface{}) (success bool, err error) {
 	rawJSON, ok := actual.(string)
 	if !ok {
-		return false, errors.Wrapf(err, "BeNodeGroupsWithNamesWhich matcher expects a string")
+		return false, fmt.Errorf("BeNodeGroupsWithNamesWhich matcher expects a string: %w", err)
 	}
 	ngSummaries := []nodegroup.Summary{}
 	if err := json.Unmarshal([]byte(rawJSON), &ngSummaries); err != nil {
-		return false, errors.Wrapf(err, "BeNodeGroupsWithNamesWhich matcher expects a Summary JSON array")
+		return false, fmt.Errorf("BeNodeGroupsWithNamesWhich matcher expects a Summary JSON array: %w", err)
 	}
 	ngNames := extractNames(ngSummaries)
 	for _, m := range matcher.matchers {
