@@ -204,7 +204,7 @@ const (
 // All valid values of supported families should go in this block
 const (
 	// DefaultNodeImageFamily (default)
-	DefaultNodeImageFamily         = NodeImageFamilyAmazonLinux2
+	DefaultNodeImageFamily         = NodeImageFamilyAmazonLinux2023
 	NodeImageFamilyAmazonLinux2023 = "AmazonLinux2023"
 	NodeImageFamilyAmazonLinux2    = "AmazonLinux2"
 	NodeImageFamilyUbuntuPro2404   = "UbuntuPro2404"
@@ -1046,6 +1046,9 @@ type ClusterConfig struct {
 	// +optional
 	Outpost *Outpost `json:"outpost,omitempty"`
 
+	// ControlPlaneScalingConfig specifies control plane scaling configuration.
+	ControlPlaneScalingConfig *ControlPlaneScalingConfig `json:"controlPlaneScalingConfig,omitempty"`
+
 	// ZonalShiftConfig specifies the zonal shift configuration.
 	ZonalShiftConfig *ZonalShiftConfig `json:"zonalShiftConfig,omitempty"`
 }
@@ -1075,6 +1078,11 @@ func (o *Outpost) HasPlacementGroup() bool {
 	return o.ControlPlanePlacement != nil
 }
 
+// ControlPlaneScalingConfig holds control plane scaling configuration.
+type ControlPlaneScalingConfig struct {
+	Tier *string `json:"tier,omitempty"`
+}
+
 // ZonalShiftConfig holds the zonal shift configuration.
 type ZonalShiftConfig struct {
 	// Enabled enables or disables zonal shift.
@@ -1960,8 +1968,8 @@ type ManagedNodeGroup struct {
 }
 
 func (n *NodeGroupBase) GetDesiredCapacity() int {
-	if n.ScalingConfig != nil && n.ScalingConfig.DesiredCapacity != nil {
-		return *n.ScalingConfig.DesiredCapacity
+	if n.ScalingConfig != nil && n.DesiredCapacity != nil {
+		return *n.DesiredCapacity
 	}
 	return 0
 }
